@@ -18,7 +18,7 @@ echo "Checking for running Fabric Manager process"
 # and if FM doesn't exit after 90sec, send SIGKILL. This form of
 # terminating is similar to systemctl stop.
 fm_proc_name="nv-fabricmanager"
-if ps aux | grep -v grep | grep "$fm_proc_name" > /dev/null; then
+if pidof "$fm_proc_name" > /dev/null; then
   echo "Fabric Manager process is running, stopping the same....."
 
   timeout=90
@@ -32,7 +32,7 @@ if ps aux | grep -v grep | grep "$fm_proc_name" > /dev/null; then
 
   while [ $(date +%s) -le "$end_time" ]; do
     # Check if the process still exists
-    if ! ps aux | grep -v grep | grep "$fm_proc_name" > /dev/null; then
+    if ! pidof "$fm_proc_name" > /dev/null; then
       echo "Fabric Manager process terminated gracefully."
       break
     fi
@@ -41,7 +41,7 @@ if ps aux | grep -v grep | grep "$fm_proc_name" > /dev/null; then
   done
 
   # If the process hasn't exited after the timeout, send SIGKILL
-  if ps aux | grep -v grep | grep "$fm_proc_name" > /dev/null; then 
+  if pidof "$fm_proc_name" > /dev/null; then 
     echo "Fabric Manager process is still running, killing the same....."
     killall -KILL "$fm_proc_name"
   fi
@@ -98,6 +98,8 @@ cp ${PWD}/gb200_nvl72r2_c2g4_topology  /usr/share/nvidia/nvswitch/
 cp ${PWD}/gb200_nvl72r2_c2g2_topology  /usr/share/nvidia/nvswitch/
 cp ${PWD}/gb200_nvl576r16_c2g4_topology  /usr/share/nvidia/nvswitch/
 cp ${PWD}/gb200_nvl8r1_c2g4_etf_topology  /usr/share/nvidia/nvswitch/
+cp ${PWD}/gb200_nvl8r1_c2g4_etf_nso_topology  /usr/share/nvidia/nvswitch/
+cp ${PWD}/gb200_nvl4r1_c2g2_etf_topology  /usr/share/nvidia/nvswitch/
 
 mkdir /usr/share/doc/nvidia-fabricmanager > /dev/null 2>&1
 cp ${PWD}/LICENSE  /usr/share/doc/nvidia-fabricmanager
